package internal

import (
	"codeup.aliyun.com/6552e56cc3b2728a4557fc18/plugin/proto"
	"encoding/json"
	"fmt"
	"plugins/alipay_cpn/internal/po"
	"plugins/alipay_cpn/internal/vo"
	"time"
)

type Config struct {
	Config *proto.Config
	Extra  *ConfigExtra
}

type ConfigExtra struct {
	Prk string `json:"prk"` // 私钥
	Npk string `json:"npk"` // 回调公钥
}

func transConfig(config *proto.Config) (*Config, error) {
	var extra ConfigExtra
	err := json.Unmarshal(config.Extra, &extra)
	if err != nil {
		return nil, err
	}
	return &Config{
		Config: config,
		Extra:  &extra,
	}, nil
}

func paramReq(config *Config, req po.Req) (*po.Param, error) {
	if err := req.Validate(); err != nil {
		return nil, err
	}
	return &po.Param{
		Timestamp:  time.Now().Format("2006-01-02 15:04:05"),
		Version:    vo.Version,
		AppId:      config.Config.AppId,
		Method:     "alipay.user.dtbankcust.channelvoucher.send",
		Format:     vo.Format,
		Charset:    vo.Charset,
		SignType:   vo.SignType,
		BizContent: string(req.ToJson()),
		Sign:       "",
	}, nil
}

func orderReq(order *proto.OrderRequest_Order, product *proto.OrderRequest_Product) (*po.OrderReq, error) {
	type Extra struct {
		LogonId string `json:"logon_id"`
		PhoneId string `json:"phone_id"`
	}
	var extra Extra
	if order.Extra != nil {
		err := json.Unmarshal(order.Extra, &extra)
		if err != nil {
			return nil, fmt.Errorf("order extra json unmarshal error: %v", err)
		}
	}
	o := &po.OrderReq{
		UserId:     order.Account,
		LogonId:    extra.LogonId,
		PhoneId:    extra.PhoneId,
		OutBizNo:   order.OrderNo,
		ActivityId: product.ProductNo,
	}
	return o, nil
}

func orderResp(request *proto.OrderRequest, resp po.OrderResp) *proto.OrderResponse {
	data, _ := json.Marshal(resp)
	return &proto.OrderResponse{
		Result: &proto.Result{
			Status:  resp.GetOrderStatus(),
			OrderNo: request.Order.OrderNo,
			TradeNo: resp.Response.VoucherId,
			Message: resp.GetMsg(),
			Data:    data,
		},
	}
}

func queryReq(in *proto.QueryRequest, chNlId string) *po.QueryReq {
	return nil
}

func queryResp(request *proto.QueryRequest, resp po.QueryResp) *proto.QueryResponse {
	return nil
}

func notifyReq(in *proto.NotifyRequest) *po.Notify {
	return nil
}

func notifyResp(request *proto.NotifyRequest, n *po.Notify) *proto.NotifyResponse {
	return nil
}
