package internal

import (
	sdkutils "codeup.aliyun.com/6552e56cc3b2728a4557fc18/plugin/utils"
	"fmt"
	"net/http"
	"plugins/union_pay_cpn/internal/po"
	"plugins/union_pay_cpn/internal/utils"
	"plugins/union_pay_cpn/internal/vo"
	"strings"
	"time"
)

func headers(config *Config, req po.Req, bizMethod string) map[string][]string {
	h := make(http.Header)
	h.Add("Content-type", vo.ContentType)
	h.Add("version", vo.Version)
	h.Add("appType", vo.AppType)
	h.Add("signMethod", vo.SignMethod)

	h.Add("appId", config.Config.AppId)
	h.Add("bizMethod", bizMethod)

	h.Add("reqId", req.GetReId())

	now := time.Now()
	milliseconds := now.Unix()*1000 + int64(now.Nanosecond())/1e6
	h.Add("reqTs", fmt.Sprintf("%d", milliseconds))

	rehash := utils.Sha(vo.Version, config.Config.AppId, bizMethod, req.GetReId(), string(req.ToJson()))
	signValue, err := utils.Sign(rehash, []byte(sdkutils.NewPrivate().Build(config.Extra.Prk)))
	if err != nil {
		return nil
	}
	h.Add("sign", signValue)
	return h
}

func verify(config *Config, req *po.Notify, notifyBizMethod string) error {
	if req.Headers.SignMethod != vo.SignMethod {
		return fmt.Errorf("签名方式不匹配")
	}
	if req.Headers.AppId != config.Config.AppId {
		return fmt.Errorf("appId不匹配")
	}
	if req.Headers.BizMethod != notifyBizMethod {
		return fmt.Errorf("业务方法不匹配")
	}
	rehash := utils.Sha(req.Headers.Version, config.Config.AppId, req.Headers.BizMethod, req.GetReId(), string(req.ToJson()))
	lowerStr := strings.ToLower(rehash)
	if utils.Verify(lowerStr, req.Headers.Sign, []byte(sdkutils.NewPublic().Build(config.Extra.Npk))) {
		return nil
	}
	return fmt.Errorf("验签失败")
}
