package internal

import (
	"codeup.aliyun.com/6552e56cc3b2728a4557fc18/plugin/proto"
	"encoding/json"
	"plugins/zltx/internal/po"
	"time"
)

func orderReq(in *proto.OrderRequest) *po.OrderReq {
	return &po.OrderReq{
		MerchantId:      in.Config.AppId,
		OutTradeNo:      in.Order.OrderNo,
		ProductId:       in.Product.ProductNo,
		RechargeAccount: in.Order.Account,
		AccountType:     1,
		Number:          in.Order.Quantity,
		Version:         "1.0",
		TimeStamp:       time.Now().Unix(),
		NotifyUrl:       in.Config.NotifyUrl,
	}
}

func orderResp(request *proto.OrderRequest, resp po.OrderResp) *proto.OrderResponse {
	data, _ := json.Marshal(resp)
	return &proto.OrderResponse{
		Result: &proto.Result{
			Status:  proto.Status_ING,
			OrderNo: request.Order.OrderNo,
			TradeNo: "", // 下单无该值返回
			Message: resp.Message,
			Data:    data,
		},
	}
}

func queryReq(in *proto.QueryRequest) *po.QueryReq {
	return &po.QueryReq{
		MerchantId: in.Config.AppId,
		OutTradeNo: in.Order.OrderNo,
		TimeStamp:  time.Now().Unix(),
		Version:    "1.0",
	}
}

func queryResp(request *proto.QueryRequest, resp po.QueryResp) *proto.QueryResponse {
	data, _ := json.Marshal(resp)
	return &proto.QueryResponse{
		Result: &proto.Result{
			Status:  resp.Status.GetOrderStatus(),
			OrderNo: request.Order.OrderNo,
			TradeNo: request.Order.TradeNo,
			Message: resp.Message,
			Data:    data,
		},
	}
}

func notifyResp(in po.Notify) *proto.NotifyResponse {
	data, _ := json.Marshal(in)
	return &proto.NotifyResponse{
		Result: &proto.Result{
			Status:  in.Status.GetOrderStatus(),
			OrderNo: in.OutTradeNo,
			TradeNo: "",
			Message: "",
			Data:    data,
		},
	}
}
